/**
Program computes parameter configurations which dominate others by having 
better cost estimate.

Author: Marius Mikucionis <marius@cs.aau.dk>

Developed as part of results for the following publication:

Alexandre David, Kim Guldstrand Larsen, Marius Mikučionis, Axel Legay and 
Dehui Du: Optmizing Control Strategy using Statistical Model Checking. 
To appear in the proceedings of NASA Formal Methods 2013.
 */

#include <iostream>
#include <iterator>
#include <algorithm>
#include <boost/bind/bind.hpp>
#include <list>

using namespace std;
using namespace boost;

struct tuple
{
  int ton, tget;
  double discomfort, energy, discomfort_err, energy_err;
  bool operator<=(const tuple& t) const {
    return (discomfort <= t.discomfort && 
	    energy <= t.energy);
  }
};

istream& operator>>(istream& is, tuple& t) 
{
  is >> t.ton >> t.tget >> t.discomfort >> t.energy
     >> t.discomfort_err >> t.energy_err;
  return is;
}

ostream& operator<<(ostream& os, const tuple& t) 
{
  os << t.ton << " " << t.tget << " " 
     << t.discomfort << " " << t.energy << " "
     << t.discomfort_err << " " << t.energy_err << endl;
  return os;
}


bool operator<=(const list<tuple>& front, const tuple& t) 
{
  return front.end() != 
    find_if(front.begin(), front.end(), 
	    bind(&tuple::operator<=, _1, t));
}

int main(int argc, const char* args[]) 
{
  list<tuple> front;
  tuple t;
  while (cin) {
    cin >> t;
    if (!(front <= t)) {
      front.erase(remove_if(front.begin(), front.end(), 
			    bind(&tuple::operator<=, t, _1)), 
		  front.end());
      front.push_back(t);
    }
  }
  copy(front.begin(), front.end(), 
       ostream_iterator<tuple>(cout));
}
