source("means.R")

system('cat means.dat | ./dominators-means > means-pareto.dat')
system('gnuplot means.plot')

# check if the data is balanced:
balance <- replications(~ . - discomfort, raw)
!is.list(balance) # should give TRUE
# check if count is the same across all combinations:
with(raw, aggregate(discomfort~Ton*Tget, FUN="length"))

### Visualization via levelplots:
require(lattice)
min_pareto<-read.table("pareto.dat", col.names=c("Ton", "Tget", "discomfort", "energy"))
mean_pareto<-read.table("means-pareto.dat", col.names=c("Ton", "Tget", "discomfort", "energy", "discomfort_2sd", "energy_2sd"))
postscript(file="discomfort-levels.eps", horizontal=F, paper="special", width=3.5, height=2.5)
levelplot(discomfort ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=0.8),
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=1.5, col="red")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget, cex=0.5, col="blue")
   })
dev.off()

postscript(file="energy-levels.eps", horizontal=F, paper="special", width=3.5, height=2.5)
levelplot(energy ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=0.8),
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=1.5, col="red")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget, cex=0.5, col="blue")
   })
dev.off()

## BIG LEVEL PLOTS:

postscript(file="discomfort-levels-b.eps", horizontal=F, paper="special", width=6, height=4)
levelplot(discomfort ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=0.8),
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=3, col="red")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget, cex=1.5, col="blue")
   })
dev.off()

postscript(file="energy-levels-b.eps", horizontal=F, paper="special", width=6, height=4)
levelplot(energy ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=0.8),
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=3, col="red")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget, cex=1.5, col="blue")
   })
dev.off()


### Troubleshooting the data:
# analyze the parameter space (to see if everything is fairly distributed):
with(head(rawdata, 600), hist(Ton, breaks=c((min(Ton)-1):max(Ton))))
with(head(rawdata, 600), hist(Tget, breaks=c((min(Tget)-1):max(Tget))))

# if frequency is not uniform, then check cumulative distribution over time:
Ton_vals<-data.frame(Ton,count=ave(Ton==Ton, Ton, FUN=cumsum))
Tget_vals<-data.frame(Tget,count=ave(Tget==Tget, Tget, FUN=cumsum))
# see if anything stands out from a line:
plot(Ton_vals[["count"]])
plot(Tget_vals[["count"]])
